==> haskell-hasql-pool-0.4.1-75-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.1
id: hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4
key: hasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 68346204662bd360b7b86b2c29364b85
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hasql-pool-0.4.1
hs-libraries: HShasql-pool-0.4.1-7bczKPc6YfOAaQ07um1BQ4
depends:
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0 time-1.8.0.2
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
abi-depends: resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             hasql-0.19.18.2-EyByh1vyBAJIpCcjYoNty0=bf40f1ab381d98128a9c155fc288832c
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.4.1-77-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.1
id: hasql-pool-0.4.1-3FBMNNOH5biJ1lnQOFFTfm
key: hasql-pool-0.4.1-3FBMNNOH5biJ1lnQOFFTfm
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 84e1949b3370e3be66ae21286e35bc8b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-pool-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hasql-pool-0.4.1
hs-libraries: HShasql-pool-0.4.1-3FBMNNOH5biJ1lnQOFFTfm
depends:
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    hasql-0.19.18.2-GI8GzEaMP4wHhtv50kPjgN time-1.8.0.2
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
abi-depends: resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             hasql-0.19.18.2-GI8GzEaMP4wHhtv50kPjgN=1d243d0be37c352193f4a48f2442582d
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
